@@ -22,6 +22,44 @@ our $INITIALIZED;
 
 __PACKAGE__->reset();
 
+##################################################
+sub cleanup {
+##################################################
+    # warn "Logger cleanup";
+
+    # Delete all loggers
+    foreach my $loggername (keys %$LOGGERS_BY_NAME){
+        # warn "Logger delete: $loggername";
+        $LOGGERS_BY_NAME->{$loggername}->DESTROY();
+        delete $LOGGERS_BY_NAME->{$loggername};
+    }
+
+    # Delete the root logger
+    undef $ROOT_LOGGER;
+
+    # Delete all appenders
+    foreach my $appendername (keys %APPENDER_BY_NAME){
+        if (exists $APPENDER_BY_NAME{$appendername} &&
+            exists $APPENDER_BY_NAME{$appendername}->{appender}) {
+                # Destroy L4p::Appender
+            $APPENDER_BY_NAME{$appendername}->DESTROY();
+            delete $APPENDER_BY_NAME{$appendername}->{appender};
+        }
+        delete $APPENDER_BY_NAME{$appendername};
+    }
+    %APPENDER_BY_NAME   = ();
+}
+
+##################################################
+sub DESTROY {
+##################################################
+    warn "Destroying logger $_[0]" if $Log::Log4perl::CHATTY_DESTROY_METHODS;
+
+    for(keys %{$_[0]}) {
+        delete $_[0]->{$_};
+    }
+}
+
 ##################################################
 sub reset {
 ##################################################
@@ -195,7 +233,7 @@ sub generate_coderef {
     }
 
     my $code = <<EOL;
-    \$coderef = sub {
+    sub {
       my (\$logger)  = shift;
       my (\$level)   = pop;
       my \$message;
@@ -250,7 +288,7 @@ sub generate_coderef {
 
 EOL
 
-    eval $code or die "$@";
+    $coderef = eval $code or die "$@";
 
     return $coderef;
 }
@@ -386,6 +424,9 @@ sub level {
     if(defined $level) {
         croak "invalid level '$level'" 
                 unless Log::Log4perl::Level::is_valid($level);
+        if ($level =~ /\D/){
+            $level = Log::Log4perl::Level::to_priority($level);
+        }
         $self->{level} = $level;   
 
         &reset_all_output_methods
@@ -626,6 +667,7 @@ sub create_log_level_methods {
                            "forgot to pass in a level string!");
   my $lclevel = lc($level);
   my $levelint = uc($level) . "_INT";
+  my $initial_cap = ucfirst($lclevel);
 
   no strict qw(refs);
 
@@ -646,6 +688,11 @@ sub create_log_level_methods {
       $_[0]->{"is_" . $level}->($_[0], "is_" . $lclevel);
   };
   
+  # Add the isXxxEnabled() methods as identical to the is_xxx
+  # functions. - dviner
+  
+  *{__PACKAGE__ . "::is".$initial_cap."Enabled"} = \&{__PACKAGE__ . "::is_$lclevel"};
+  
   use strict qw(refs);
 
   return 0;
